==> cstructs-0.2.2.tar.gz: cstructs-0.2.2/src/cstructs/__init__.py <==
# --------------------------------------------------------------------------------------
#  Copyright(C) 2023 yntha                                                             -
#                                                                                      -
#  This program is free software: you can redistribute it and/or modify it under       -
#  the terms of the GNU General Public License as published by the Free Software       -
#  Foundation, either version 3 of the License, or (at your option) any later          -
#  version.                                                                            -
#                                                                                      -
#  This program is distributed in the hope that it will be useful, but WITHOUT ANY     -
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A     -
#  PARTICULAR PURPOSE. See the GNU General Public License for more details.            -
#                                                                                      -
#  You should have received a copy of the GNU General Public License along with        -
#  this program. If not, see <http://www.gnu.org/licenses/>.                           -
# --------------------------------------------------------------------------------------
from cstructs.datastruct import datastruct as backend_datastruct, DataStruct
from cstructs.nativetypes import NativeTypes


def datastruct(*args, **kwargs):
    return backend_datastruct(*args, **kwargs)

==> cstructs-0.2.5.tar.gz: cstructs-0.2.5/src/cstructs/__init__.py <==
# --------------------------------------------------------------------------------------
#  Copyright(C) 2023 yntha                                                             -
#                                                                                      -
#  This program is free software: you can redistribute it and/or modify it under       -
#  the terms of the GNU General Public License as published by the Free Software       -
#  Foundation, either version 3 of the License, or (at your option) any later          -
#  version.                                                                            -
#                                                                                      -
#  This program is distributed in the hope that it will be useful, but WITHOUT ANY     -
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A     -
#  PARTICULAR PURPOSE. See the GNU General Public License for more details.            -
#                                                                                      -
#  You should have received a copy of the GNU General Public License along with        -
#  this program. If not, see <http://www.gnu.org/licenses/>.                           -
# --------------------------------------------------------------------------------------
from cstructs.datastruct import (
    datastruct as backend_datastruct,
    DataStruct,
    Sequence,
    Member,
    MemberRef,
)
from cstructs.nativetypes import NativeTypes


def datastruct(*args, **kwargs):
    return backend_datastruct(*args, **kwargs)
